@@ -1,6 +1,6 @@
 ;;; parser-generator-lr-export.el --- Export LR(k) Parser -*- lexical-binding: t -*-
 
-;; Copyright (C) 2020-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2020-2025  Free Software Foundation, Inc.
 
 
 ;;; Commentary:
@@ -40,10 +40,10 @@
     (error "Table for terminals is undefined!"))
   (unless parser-generator--table-translations
     (error "Table for translations by production-number is undefined!"))
-  (unless parser-generator-lex-analyzer--get-function
-    (error "Missing lex-analyzer get function!"))
-  (unless parser-generator-lex-analyzer--function
-    (error "Missing lex-analyzer function!"))
+  (unless parser-generator-lex-analyzer--get-function-export-source
+    (error "Missing lex-analyzer get function export source!"))
+  (unless parser-generator-lex-analyzer--function-export-source
+    (error "Missing lex-analyzer function export source!"))
 
   (let ((code))
     (with-temp-buffer
@@ -186,30 +186,25 @@
       ;; Lex-Analyzer Get Function
       (insert
        (format
-        "(defvar\n  %s-lex-analyzer--get-function\n  (lambda %S %S)\n  \"The lex-analyzer get function.\")\n\n"
+        "(defvar\n  %s-lex-analyzer--get-function\n  %s\n  \"The lex-analyzer get function.\")\n\n"
         namespace
-        (aref parser-generator-lex-analyzer--get-function 0)
-        (car (aref parser-generator-lex-analyzer--get-function 1))))
+        parser-generator-lex-analyzer--get-function-export-source))
 
       ;; Lex-Analyzer Function
       (insert
        (format
-        "(defvar\n  %s-lex-analyzer--function\n  (lambda %S %S)\n  \"The lex-analyzer function.\")\n\n"
+        "(defvar\n  %s-lex-analyzer--function\n  %s\n  \"The lex-analyzer function.\")\n\n"
         namespace
-        (aref parser-generator-lex-analyzer--function 0)
-        (car (aref parser-generator-lex-analyzer--function 1))))
+        parser-generator-lex-analyzer--function-export-source))
 
       ;; Lex-Analyzer Reset Function
       (insert
        (format
         "(defvar\n  %s-lex-analyzer--reset-function\n  "
         namespace))
-      (if parser-generator-lex-analyzer--reset-function
+      (if (not (equal parser-generator-lex-analyzer--reset-function-export-source ""))
           (insert
-           (format
-            "(lambda %S %S)\n"
-            (aref parser-generator-lex-analyzer--reset-function 0)
-            (car (aref parser-generator-lex-analyzer--reset-function 1))))
+           parser-generator-lex-analyzer--reset-function-export-source)
         (insert "nil\n"))
       (insert "  \"The lex-analyzer reset function.\")\n\n")
 
